import pandas as pd
from ._adverse_impact_ratio_by_quantile_column_type import AdverseImpactRatioByQuantileColumnType as AdverseImpactRatioByQuantileColumnType
from ._adverse_impact_ratio_column_type import AdverseImpactRatioColumnType as AdverseImpactRatioColumnType
from ._disparity_calculation import DisparityCalculation as DisparityCalculation
from ._odds_ratio_column_type import OddsRatioColumnType as OddsRatioColumnType
from ._residual_smd_denominator import ResidualSMDDenominator as ResidualSMDDenominator
from ._residual_standardized_mean_difference_column_type import ResidualStandardizedMeanDifferenceColumnType as ResidualStandardizedMeanDifferenceColumnType
from ._segmented_adverse_impact_ratio_column_type import SegmentedAdverseImpactRatioColumnType as SegmentedAdverseImpactRatioColumnType
from ._smd_denominator import SMDDenominator as SMDDenominator
from ._standardized_mean_difference_column_type import StandardizedMeanDifferenceColumnType as StandardizedMeanDifferenceColumnType
from ._stat_sig import StatSig as StatSig
from ._stat_sig_hypothesis import StatSigHypothesis as StatSigHypothesis
from ._stat_sig_test import StatSigTest as StatSigTest
from _typeshed import Incomplete
from pathlib import Path
from solas_disparity import const as const, ui as ui
from solas_disparity.output._plot import plot as plot
from typing import List, Optional, Union

class Disparity:
    plot: Incomplete
    def __attrs_post_init__(self) -> None: ...
    disparity_type: DisparityCalculation
    summary_table: pd.DataFrame
    protected_groups: List[str]
    reference_groups: List[str]
    group_categories: List[str]
    statistical_significance: StatSig
    stat_sig_test: Optional[Union[str, StatSigTest]]
    stat_sig_p_values: Optional[pd.Series]
    stat_sig_summary_table: Optional[pd.DataFrame]
    stat_sig_t_statistics: Optional[pd.DataFrame]
    stat_sig_standard_errors: Optional[pd.DataFrame]
    smd_threshold: Optional[float]
    residual_smd_threshold: Optional[float]
    smd_denominator: Optional[str]
    residual_smd_denominator: Optional[str]
    lower_score_favorable: Optional[bool]
    odds_ratio_threshold: Optional[float]
    air_threshold: Optional[float]
    percent_difference_threshold: Optional[float]
    population_percent_favorable: Optional[float]
    max_for_fishers: Optional[int]
    alternative_hypothesis: Optional[Union[str, StatSigHypothesis]]
    quantile_summaries: Optional[List[pd.DataFrame]]
    category_summaries: Optional[List[pd.DataFrame]]
    summary_table_hstacked: Optional[pd.DataFrame]
    quantile_air_results: Optional[List[Disparity]]
    categorical_air_results: Optional[List[Disparity]]
    quantile_statistical_significance_results: Optional[List[StatSig]]
    category_statistical_significance_results: Optional[List[StatSig]]
    input_quantiles: Optional[List[float]]
    ordinal_categories: Optional[List[float]]
    quantile_cutoffs_table: Optional[pd.DataFrame]
    outcome_category_mapping: Optional[pd.DataFrame]
    segment_air_results: Optional[List[Disparity]]
    segment_summaries: Optional[List[pd.DataFrame]]
    segment_statistical_significance_results: Optional[List[StatSig]]
    segments: Optional[List[Union[int, float, str]]]
    summary_table_across_segments: Optional[pd.DataFrame]
    summary_table_by_segments: Optional[pd.DataFrame]
    fdr_threshold: Optional[float]
    @property
    def affected_groups(self) -> List[str]: ...
    @property
    def affected_groups_by_segment(self) -> Optional[List[str]]: ...
    @property
    def affected_reference_by_segment(self) -> Optional[List[str]]: ...
    @property
    def affected_categories_by_segment(self) -> Optional[List[str]]: ...
    @property
    def affected_reference(self) -> List[str]: ...
    @property
    def affected_categories(self) -> Optional[List[str]]: ...
    @property
    def observations(self) -> pd.DataFrame: ...
    @property
    def percent_missing(self) -> pd.DataFrame: ...
    @property
    def total(self) -> pd.DataFrame: ...
    @property
    def average_label(self) -> Optional[pd.DataFrame]: ...
    @property
    def average_outcome(self) -> Optional[pd.DataFrame]: ...
    @property
    def average_prediction(self) -> Optional[pd.DataFrame]: ...
    @property
    def average_residual(self) -> Optional[pd.DataFrame]: ...
    @property
    def outcome_std(self) -> Optional[pd.DataFrame]: ...
    @property
    def residual_std(self) -> Optional[pd.DataFrame]: ...
    @property
    def label_favorable(self) -> Optional[pd.DataFrame]: ...
    @property
    def label_unfavorable(self) -> Optional[pd.DataFrame]: ...
    @property
    def percent_label_favorable(self) -> Optional[pd.DataFrame]: ...
    @property
    def percent_label_unfavorable(self) -> Optional[pd.DataFrame]: ...
    @property
    def favorable(self) -> Optional[pd.DataFrame]: ...
    @property
    def unfavorable(self) -> Optional[pd.DataFrame]: ...
    @property
    def percent_favorable(self) -> Optional[pd.DataFrame]: ...
    @property
    def percent_unfavorable(self) -> Optional[pd.DataFrame]: ...
    @property
    def percent_difference_favorable(self) -> Optional[pd.DataFrame]: ...
    @property
    def percent_difference_unfavorable(self) -> Optional[pd.DataFrame]: ...
    @property
    def odds(self) -> Optional[pd.DataFrame]: ...
    @property
    def label_odds(self) -> Optional[pd.DataFrame]: ...
    @property
    def odds_ratio(self) -> Optional[pd.DataFrame]: ...
    @property
    def smd(self) -> Optional[pd.DataFrame]: ...
    @property
    def residual_smd(self) -> Optional[pd.DataFrame]: ...
    @property
    def air(self) -> Optional[pd.DataFrame]: ...
    @property
    def p_values(self) -> pd.DataFrame: ...
    @property
    def practically_significant(self) -> pd.DataFrame: ...
    @property
    def benjamani_hochberg_critical_value(self) -> Optional[pd.DataFrame]: ...
    @property
    def quantiles(self) -> Optional[List]: ...
    @property
    def quantile_cutoffs(self) -> Optional[List]: ...
    @property
    def categories(self) -> Optional[List]: ...
    def to_csv(self, file_path: Union[str, Path]) -> None: ...
    def to_excel(self, file_path: Union[str, Path]): ...
    def show(self) -> None: ...
    def __rich__(self) -> None: ...
    def to_image(self, file_path: Union[str, Path], column: Union[str, AdverseImpactRatioColumnType, AdverseImpactRatioByQuantileColumnType, SegmentedAdverseImpactRatioColumnType, StandardizedMeanDifferenceColumnType, ResidualStandardizedMeanDifferenceColumnType, OddsRatioColumnType], group: Optional[str] = ..., condense: Optional[bool] = ..., top_n_segments: Optional[int] = ...) -> None: ...
    def __init__(self, plot, disparity_type, summary_table, protected_groups, reference_groups, group_categories, statistical_significance, stat_sig_test, stat_sig_p_values, stat_sig_summary_table, stat_sig_t_statistics, stat_sig_standard_errors, smd_threshold, residual_smd_threshold, smd_denominator, residual_smd_denominator, lower_score_favorable, odds_ratio_threshold, air_threshold, percent_difference_threshold, population_percent_favorable, max_for_fishers, alternative_hypothesis, quantile_summaries, category_summaries, summary_table_hstacked, quantile_air_results, categorical_air_results, quantile_statistical_significance_results, category_statistical_significance_results, input_quantiles, ordinal_categories, quantile_cutoffs_table, outcome_category_mapping, segment_air_results, segment_summaries, segment_statistical_significance_results, segments, summary_table_across_segments, summary_table_by_segments, fdr_threshold) -> None: ...
    def __lt__(self, other): ...
    def __le__(self, other): ...
    def __gt__(self, other): ...
    def __ge__(self, other): ...
